==> hlw-core-0.0.2-20250828.021836-145-sources.jar: cn/gtmap/hlw/coredk/dto/olcommon/kqtb/CrossRiverSqxxModelDTO.java <==
package cn.gtmap.hlw.coredk.dto.olcommon.kqtb;


import cn.gtmap.estateplat.register.common.entity.GxYyLdxx;
import cn.gtmap.estateplat.register.common.entity.GxYySqxxCfxx;
import cn.gtmap.estateplat.register.common.entity.GxYySqxxFsss;
import cn.gtmap.estateplat.register.common.entity.GxYySqxxGhxx;
import cn.gtmap.estateplat.register.common.entity.GxYySqxxTdcbjy;
import cn.gtmap.estateplat.register.common.entity.GxYySqxxTdcbjydkxx;
import cn.gtmap.estateplat.register.common.entity.WctJyDjxx;
import cn.gtmap.estateplat.register.common.entity.*;
import cn.gtmap.hlw.core.model.GxYySqxxDyxx;
import cn.gtmap.hlw.core.model.*;
import lombok.Data;

import java.util.List;

/**
 * 跨江通办申请信息保存
 *
 * @author <a href="mailto:chengong@gtmap.cn">chengong</a>
 * @see [相关类/方法]（可选）
 * @since [产品/模块版本] （可选）
 */
@Data
public class CrossRiverSqxxModelDTO  {
    /**
     * 受理编号
     */
    private String slbh;

    /**
     * 申请标识码
     */
    private String sqbsm;

    /**
     * 原受理编号
     */
    private String ySlbh;

    /**
     * 申请信息
     */
    private Sqxx sqxx;

    /**
     * 公积金申请信息
     */
    private Sqxx gjjSqxx;

    /**
     * 申请信息 批量
     */
    private List<Sqxx> sqxxList;
    /**
     * 权利人
     */
    private List<Qlr> qlrList;

    /**
     * 房屋信息
     */
    private GxYyFwxx fwXx;

    /**
     * 土地信息
     */
    private GxYySqxxTdxx gxYyTdxx;

    /**
     * 合同信息
     */
    private GxYySqxxHtxx gxYyHtxx;

    /**
     * 林地信息
     */
    private GxYyLdxx ldxx;

    /**
     * 办件节点
     */
    private String bjjd;

    /**
     * 评价
     */
    private GxYyEvaluate gxYyEvaluate;

    /**
     * 一窗的产权证信息
     */
//    private ResponseCqzxxDataDetailEntity cqxx;

    /**
     * 分别持证，权利人产权信息
     */
    private List<Qlr> qlrCqxx;

    /**
     * 申请信息——中介信息
     */
    private SqxxZjxx sqxxZjxx;

    /**
     * 共有人信息
     */
//    private RequestInitSqxxGxrxxEntity sqxxGxrxx;

    /**
     * 预约编号
     */
    private String yyh;

    /**
     * 合同附件信息
     */
//    private List<ResponseHtfjListDataEntity> htfjList;

    /**
     * 税务信息
     */
    private List<GxYySqxxSw> swList;

    /**
     * 资金监管信息
     */
    private GxYySqxxZjjg gxYySqxxZjjg;

    /**
     * 区域代码
     */
    private String qydm;

    /**
     * 在线申请 登记中心 控制信息是否展示
     */
//    private String zxsq_djzx = AppConfig.getProperty("sqxx.djzx");

    /**
     * 在线申请 区域代码 控制信息是否展示
     */
//    private String zxsq_qydm = AppConfig.getProperty("sqxx.qydm");

    /**
     * 查封信息
     */
    private GxYySqxxCfxx cfxx;

    /**
     * 发票信息
     */
    private List<GxYySqxxFpxx> fpList;


    /**
     * 申请信息变更
     */
    private SqxxBg sqxxBg;

    /**
     * 税务减免信息
     */
    private Qlr swjmxx;

    /**
     * 申请信息物流信息
     */
    private List<SqxxWlxx> wlxxList;

    /**
     * 水电气过户信息
     */
    private List<GxYySqxxGhxx> ghxxList;

    /**
     * 抵押信息
     */
    private List<GxYySqxxDyxx> dyxxList;

    /**
     * 预约信息
     */
    private GxyyYyxx yyxx;

    /**
     * 收费信息列表
     */
    private List<WctJyDjxx> sfxxList;

    /**
     * 申请信息-附属设施
     */
    private List<GxYySqxxFsss> fsssList;


    /**
     * 申请信息-附属设施合同
     */
    private List<GxYySqxxFsss> fsssHtList;

    /**
     * 是否发送短信 0否,1是
     */
    private String sffsdx;

    /**
     * 居住权
     */
    private GxYyJzq gxYyJzq;
    /**
     * 是否推送登记
     */
    private String sftsdj;
    /**
     * 构筑物信息
     */
    private GxYySqxxGzwxx gxYyGzwxx;
    /**
     * 地役信息
     */
    private GxYySqxxDiyixx gxYyDiyixx;
    /**
     * 异议信息
     */
    private GxYySqxxYiyixx gxYyYiyixx;
    /**
     * 外联证书信息
     */
    private List<GxYySqxxWlzsxx> wlzsxxList;

    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 地籍调查表
     */
    private GxYyDjdc gxYyDjdc;

    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description gx_yy_djdcdwxx
     */
//    private List<GxYyDjdcdwxxDO> gxYyDjdcdwxxList;
    /**
     * 竣工信息
     */
//    private GxYySqxxJgxx gxYySqxxJgxx;
    /**
     * 土地承包经营
     */
    private GxYySqxxTdcbjy gxYySqxxTdcbjy;
    /**
     * 土地承包经营地块信息
     */
    private GxYySqxxTdcbjydkxx gxYySqxxTdcbjydkxx;
    /**
     * 土地经营信息
     */
//    private GxYySqxxTdjyDTO gxYySqxxTdjy;
    /**
     * 是否核验 0否,1是 默认1
     */
    private String sfhy;
    /**
     * 是否重新编辑 0否,1是 默认0
     */
    private String isEdit;

    /**
     * 海域信息
     */
//    private GxYySqxxHyxxDTO gxYySqxxHyxx;
    /**
     * 维修基金信息
     */
//    private GxYySqxxWxjjDTO gxYySqxxWxjj;

    private SqxxCdxx cdxx;
    /**
     * 附件项目
     */
    private List<CrossRiverFjxmDTO> fjxmList;

    /**
     * 附件信息
     */
    private List<CrossRiverFjxxDTO> fjxxList;


}

==> hlw-core-0.0.2-20251028.074645-168-sources.jar: cn/gtmap/hlw/coredk/dto/olcommon/kqtb/CrossRiverSqxxModelDTO.java <==
package cn.gtmap.hlw.coredk.dto.olcommon.kqtb;


import cn.gtmap.hlw.core.model.CrossRiver.GxYyEvaluate;
import cn.gtmap.hlw.core.model.CrossRiver.Qlr;
import cn.gtmap.hlw.core.model.CrossRiver.Sqxx;
import cn.gtmap.hlw.core.model.*;
import lombok.Data;

import java.util.List;

/**
 * 跨江通办申请信息保存
 *
 * @author <a href="mailto:chengong@gtmap.cn">chengong</a>
 * @see [相关类/方法]（可选）
 * @since [产品/模块版本] （可选）
 */
@Data
public class CrossRiverSqxxModelDTO  {
    /**
     * 受理编号
     */
    private String slbh;

    /**
     * 申请标识码
     */
    private String sqbsm;

    /**
     * 原受理编号
     */
    private String ySlbh;

    /**
     * 申请信息
     */
    private Sqxx sqxx;

    /**
     * 公积金申请信息
     */
    private Sqxx gjjSqxx;

    /**
     * 申请信息 批量
     */
    private List<Sqxx> sqxxList;
    /**
     * 权利人
     */
    private List<Qlr> qlrList;

    /**
     * 房屋信息
     */
    private GxYyFwxx fwXx;

    /**
     * 土地信息
     */
    private GxYySqxxTdxx gxYyTdxx;

    /**
     * 合同信息
     */
    private GxYySqxxHtxx gxYyHtxx;

    /**
     * 林地信息
     */
    private GxYyLdxx ldxx;

    /**
     * 办件节点
     */
    private String bjjd;

    /**
     * 评价
     */
    private GxYyEvaluate gxYyEvaluate;

    /**
     * 一窗的产权证信息
     */
//    private ResponseCqzxxDataDetailEntity cqxx;

    /**
     * 分别持证，权利人产权信息
     */
    private List<Qlr> qlrCqxx;

    /**
     * 申请信息——中介信息
     */
    private GxYySqxxZjxx sqxxZjxx;

    /**
     * 共有人信息
     */
//    private RequestInitSqxxGxrxxEntity sqxxGxrxx;

    /**
     * 预约编号
     */
    private String yyh;

    /**
     * 合同附件信息
     */
//    private List<ResponseHtfjListDataEntity> htfjList;

    /**
     * 税务信息
     */
    private List<GxYySqxxSw> swList;

    /**
     * 资金监管信息
     */
    private GxYySqxxZjjg gxYySqxxZjjg;

    /**
     * 区域代码
     */
    private String qydm;

    /**
     * 在线申请 登记中心 控制信息是否展示
     */
//    private String zxsq_djzx = AppConfig.getProperty("sqxx.djzx");

    /**
     * 在线申请 区域代码 控制信息是否展示
     */
//    private String zxsq_qydm = AppConfig.getProperty("sqxx.qydm");

    /**
     * 查封信息
     */
    private GxYySqxxCfxx cfxx;

    /**
     * 发票信息
     */
    private List<GxYySqxxFpxx> fpList;


    /**
     * 申请信息变更
     */
    private GxYySqxxBg sqxxBg;

    /**
     * 税务减免信息
     */
    private Qlr swjmxx;

    /**
     * 申请信息物流信息
     */
    private List<GxYySqxxWlxx> wlxxList;

    /**
     * 水电气过户信息
     */
    private List<GxYySqxxGhxx> ghxxList;

    /**
     * 抵押信息
     */
    private List<GxYySqxxDyxx> dyxxList;

    /**
     * 预约信息
     */
    private GxYyYyxx yyxx;

    /**
     * 收费信息列表
     */
    private List<WctJyDjxx> sfxxList;

    /**
     * 申请信息-附属设施
     */
    private List<GxYySqxxFsss> fsssList;


    /**
     * 申请信息-附属设施合同
     */
    private List<GxYySqxxFsss> fsssHtList;

    /**
     * 是否发送短信 0否,1是
     */
    private String sffsdx;

    /**
     * 居住权
     */
    private GxYyJzq gxYyJzq;
    /**
     * 是否推送登记
     */
    private String sftsdj;
    /**
     * 构筑物信息
     */
    private GxYySqxxGzwxx gxYyGzwxx;
    /**
     * 地役信息
     */
    private GxYySqxxDiyixx gxYyDiyixx;
    /**
     * 异议信息
     */
    private GxYySqxxYiyixx gxYyYiyixx;
    /**
     * 外联证书信息
     */
    private List<GxYySqxxWlzsxx> wlzsxxList;

    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 地籍调查表
     */
    private GxYyDjdc gxYyDjdc;

    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description gx_yy_djdcdwxx
     */
//    private List<GxYyDjdcdwxxDO> gxYyDjdcdwxxList;
    /**
     * 竣工信息
     */
//    private GxYySqxxJgxx gxYySqxxJgxx;
    /**
     * 土地承包经营
     */
    private GxYySqxxTdcbjy gxYySqxxTdcbjy;
    /**
     * 土地承包经营地块信息
     */
    private GxYySqxxTdcbjydkxx gxYySqxxTdcbjydkxx;
    /**
     * 土地经营信息
     */
//    private GxYySqxxTdjyDTO gxYySqxxTdjy;
    /**
     * 是否核验 0否,1是 默认1
     */
    private String sfhy;
    /**
     * 是否重新编辑 0否,1是 默认0
     */
    private String isEdit;

    /**
     * 海域信息
     */
//    private GxYySqxxHyxxDTO gxYySqxxHyxx;
    /**
     * 维修基金信息
     */
//    private GxYySqxxWxjjDTO gxYySqxxWxjj;

    private GxYyCdxx cdxx;
    /**
     * 附件项目
     */
    private List<CrossRiverFjxmDTO> fjxmList;

    /**
     * 附件信息
     */
    private List<CrossRiverFjxxDTO> fjxxList;


}
